[llvm-commits] [llvm] r109355 - /llvm/trunk/lib/Transforms/Utils/ValueMapper.cpp

Nick Lewycky nicholas at mxc.ca
Sat Jul 24 13:54:02 PDT 2010


Author: nicholas
Date: Sat Jul 24 15:54:02 2010
New Revision: 109355

URL: http://llvm.org/viewvc/llvm-project?rev=109355&view=rev
Log:
Revert this because we can't clone cyclic MDNodes which are creating during a
build of llvm-gcc.

Modified:
    llvm/trunk/lib/Transforms/Utils/ValueMapper.cpp

Modified: llvm/trunk/lib/Transforms/Utils/ValueMapper.cpp
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/lib/Transforms/Utils/ValueMapper.cpp?rev=109355&r1=109354&r2=109355&view=diff
==============================================================================
--- llvm/trunk/lib/Transforms/Utils/ValueMapper.cpp (original)
+++ llvm/trunk/lib/Transforms/Utils/ValueMapper.cpp Sat Jul 24 15:54:02 2010
@@ -27,9 +27,10 @@
   // NOTE: VMSlot can be invalidated by any reference to VM, which can grow the
   // DenseMap.  This includes any recursive calls to MapValue.
 
-  // Global values do not need to be seeded into the VM if they are using
-  // the identity mapping.
-  if (isa<GlobalValue>(V) || isa<InlineAsm>(V) || isa<MDString>(V))
+  // Global values and non-function-local metadata do not need to be seeded into
+  // the VM if they are using the identity mapping.
+  if (isa<GlobalValue>(V) || isa<InlineAsm>(V) || isa<MDString>(V) ||
+      (isa<MDNode>(V) && !cast<MDNode>(V)->isFunctionLocal()))
     return VMSlot = const_cast<Value*>(V);
 
   if (const MDNode *MD = dyn_cast<MDNode>(V)) {





More information about the llvm-commits mailing list